window.Gleam.initSearch([{"doc":"glog","title":"glog","content":"# glog\n\n[![Package Version](https://img.shields.io/hexpm/v/glog)](https://hex.pm/packages/glog)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glog/)\n\nA Gleam implementation of Erlang logger inspired from [Logrus](https://github.com/sirupsen/logrus) API.\n\n![](assets/small_glog_logo.png)\n\n## Task List\n\n- [x] Write documentation\n- [x] Add unit tests\n- [x] Improve API with `add_error`, `add_result` `add_option`...\n- [ ] Add an API to configure the logger (custom configuration file)\n\n## Usage\n\nThe Erlang logger is asynchronous by default, please read the [logger chapter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#message-queue-length)\n\n```gleam\nimport glog\nimport glog/field\nimport glog/arg\nimport glog/level\n\n\npub fn main() {\n  let logger = glog.new()\n  glog.set_primary_log_level(level.All)\n  glog.set_default_config()\n\n  logger\n  |&gt; glog.add(&quot;foo&quot;, &quot;bar&quot;)\n  |&gt; glog.add_field(field.new(&quot;woo&quot;, &quot;zoo&quot;))\n  |&gt; glog.infof(&quot;I&#39;ll be ~p&quot;, [arg.new(&quot;back&quot;)])\n}\n```\n\n## Things to know\n\n* Gleam do not support configuration files at the moment. To load a custom Erlang config file use the following\n  command: `ERL_FLAGS=&#39;-config &lt;config_file&gt;&#39; gleam run`\n    * Please read the [logger documentation](https://www.erlang.org/doc/man/logger.html) to know more about\n      configuration files\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add glog\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glog&gt;.\n","url":"index.html"},{"doc":"glog/arg","title":"Arg","content":"pub type Arg {\n  Arg(value: Dynamic)\n}\n Arg opaque representation\nArg(value: Dynamic)\n\n\nSynonyms:\nglog/arg.Arg\nglog/arg Arg","url":"glog/arg.html#Arg"},{"doc":"glog/arg","title":"Args","content":"pub type Args =\n  List(Arg)\n Type alias representing an Arg list\n\nSynonyms:\nglog/arg.Args\nglog/arg Args","url":"glog/arg.html#Args"},{"doc":"glog/arg","title":"new","content":"pub fn new(value: a) -&gt; Arg\n Initializes a new Arg\nSynonyms:\nglog/arg.new\nglog/arg new","url":"glog/arg.html#new"},{"doc":"glog/arg","title":"value","content":"pub fn value(field: Arg) -&gt; Dynamic\n Fetches value from Arg\nSynonyms:\nglog/arg.value\nglog/arg value","url":"glog/arg.html#value"},{"doc":"glog/arg","title":"glog/arg","content":"","url":"glog/arg.html"},{"doc":"glog/field","title":"Field","content":"pub type Field {\n  Field(key: String, value: Dynamic)\n}\n Field representation\nField(key: String, value: Dynamic)\n\n\nSynonyms:\nglog/field.Field\nglog/field Field","url":"glog/field.html#Field"},{"doc":"glog/field","title":"Fields","content":"pub type Fields =\n  List(Field)\n Type alias representing a Field list\n\nSynonyms:\nglog/field.Fields\nglog/field Fields","url":"glog/field.html#Fields"},{"doc":"glog/field","title":"key","content":"pub fn key(field: Field) -&gt; String\n Fetches key from Field\nSynonyms:\nglog/field.key\nglog/field key","url":"glog/field.html#key"},{"doc":"glog/field","title":"new","content":"pub fn new(key: String, value: a) -&gt; Field\n Initializes a new Field\nSynonyms:\nglog/field.new\nglog/field new","url":"glog/field.html#new"},{"doc":"glog/field","title":"value","content":"pub fn value(field: Field) -&gt; Dynamic\n Fetches value from Field\nSynonyms:\nglog/field.value\nglog/field value","url":"glog/field.html#value"},{"doc":"glog/field","title":"glog/field","content":"","url":"glog/field.html"},{"doc":"glog/level","title":"Alert","content":"pub type Alert\n action must be taken immediately\n\nSynonyms:\nglog/level.Alert\nglog/level Alert","url":"glog/level.html#Alert"},{"doc":"glog/level","title":"All","content":"pub type All\n all levels\n\nSynonyms:\nglog/level.All\nglog/level All","url":"glog/level.html#All"},{"doc":"glog/level","title":"ConfigLevel","content":"pub type ConfigLevel {\n  Level\n  All\n  None\n}\n Logger levels valid configuration list\nLevel\n\n\nAll\n\n\nNone\n\n\nSynonyms:\nglog/level.ConfigLevel\nglog/level ConfigLevel","url":"glog/level.html#ConfigLevel"},{"doc":"glog/level","title":"Critical","content":"pub type Critical\n critical conditions\n\nSynonyms:\nglog/level.Critical\nglog/level Critical","url":"glog/level.html#Critical"},{"doc":"glog/level","title":"Debug","content":"pub type Debug\n debug-level messages\n\nSynonyms:\nglog/level.Debug\nglog/level Debug","url":"glog/level.html#Debug"},{"doc":"glog/level","title":"Emergency","content":"pub type Emergency\n system is unusable\n\nSynonyms:\nglog/level.Emergency\nglog/level Emergency","url":"glog/level.html#Emergency"},{"doc":"glog/level","title":"Error","content":"pub type Error\n error conditions\n\nSynonyms:\nglog/level.Error\nglog/level Error","url":"glog/level.html#Error"},{"doc":"glog/level","title":"Info","content":"pub type Info\n informational messages\n\nSynonyms:\nglog/level.Info\nglog/level Info","url":"glog/level.html#Info"},{"doc":"glog/level","title":"Level","content":"pub type Level {\n  Emergency\n  Alert\n  Critical\n  Error\n  Warning\n  Notice\n  Info\n  Debug\n}\n Logger levels valid list\nEmergency\n\n\nAlert\n\n\nCritical\n\n\nError\n\n\nWarning\n\n\nNotice\n\n\nInfo\n\n\nDebug\n\n\nSynonyms:\nglog/level.Level\nglog/level Level","url":"glog/level.html#Level"},{"doc":"glog/level","title":"None","content":"pub type None\n No level\n\nSynonyms:\nglog/level.None\nglog/level None","url":"glog/level.html#None"},{"doc":"glog/level","title":"Notice","content":"pub type Notice\n normal but significant conditions\n\nSynonyms:\nglog/level.Notice\nglog/level Notice","url":"glog/level.html#Notice"},{"doc":"glog/level","title":"Warning","content":"pub type Warning\n warning conditions\n\nSynonyms:\nglog/level.Warning\nglog/level Warning","url":"glog/level.html#Warning"},{"doc":"glog/level","title":"glog/level","content":"","url":"glog/level.html"},{"doc":"glog","title":"Glog","content":"pub opaque type Glog\n A Gleam implementation of Erlang logger\n Glog is the current &quot;state&quot; of the log to print\n\nSynonyms:\nglog.Glog\nglog Glog","url":"glog.html#Glog"},{"doc":"glog","title":"add","content":"pub fn add(logger: Glog, key: String, value: a) -&gt; Glog\n Adds a key/value to the current log\n\n ### Usage\n \n import glog.{type Glog}\n\n let logger: Glog = glog.new()\n logger\n |&gt; add(&quot;foo&quot;, &quot;bar&quot;)\n |&gt; add(&quot;woo&quot;, &quot;zoo&quot;)\n \nSynonyms:\nglog.add\nglog add","url":"glog.html#add"},{"doc":"glog","title":"add_error","content":"pub fn add_error(logger: Glog, error: a) -&gt; Glog\n Adds an error key to the current log\n\n ### Usage\n \n import glog.{type Glog}\n import glog/field\n\n let logger: Glog = glog.new()\n logger\n |&gt; add_error(&quot;foo&quot;)\n \nSynonyms:\nglog.add_error\nglog add_error","url":"glog.html#add_error"},{"doc":"glog","title":"add_field","content":"pub fn add_field(logger: Glog, f: Field) -&gt; Glog\n Adds a Field to the current log\n\n ### Usage\n \n import glog.{type Glog}\n import glog/field\n\n let logger: Glog = glog.new()\n logger\n |&gt; add_field(field.new(&quot;foo&quot;, &quot;bar&quot;))\n \nSynonyms:\nglog.add_field\nglog add_field","url":"glog.html#add_field"},{"doc":"glog","title":"add_fields","content":"pub fn add_fields(logger: Glog, f: List(Field)) -&gt; Glog\n Adds Fields to the current log\n\n ### Usage\n \n import glog.{type Glog}\n import glog/field\n\n let logger: Glog = glog.new()\n logger\n |&gt; add_fields([field.new(&quot;foo&quot;, &quot;bar&quot;), field.new(&quot;woo&quot;, &quot;zoo&quot;)])\n \nSynonyms:\nglog.add_fields\nglog add_fields","url":"glog.html#add_fields"},{"doc":"glog","title":"add_option","content":"pub fn add_option(\n  logger: Glog,\n  key: String,\n  o: Option(a),\n) -&gt; Glog\n Adds an Option to the current log\n\n ### Usage\n \n import glog.{type Glog}\n import glog/field\n\n let logger: Glog = glog.new()\n logger\n |&gt; add_option(&quot;foo&quot;, Some(&quot;foo&quot;))\n \nSynonyms:\nglog.add_option\nglog add_option","url":"glog.html#add_option"},{"doc":"glog","title":"add_result","content":"pub fn add_result(\n  logger: Glog,\n  key: String,\n  r: Result(a, b),\n) -&gt; Glog\n Adds a Result to the current log\n\n ### Usage\n \n import glog.{type Glog}\n import glog/field\n\n let logger: Glog = glog.new()\n logger\n |&gt; add_result(&quot;foo&quot;, Ok(&quot;foo&quot;))\n \nSynonyms:\nglog.add_result\nglog add_result","url":"glog.html#add_result"},{"doc":"glog","title":"alert","content":"pub fn alert(logger: Glog, message: String) -&gt; Glog\n Prints Alert log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.alert\nglog alert","url":"glog.html#alert"},{"doc":"glog","title":"alertf","content":"pub fn alertf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Alert log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.alertf\nglog alertf","url":"glog.html#alertf"},{"doc":"glog","title":"critical","content":"pub fn critical(logger: Glog, message: String) -&gt; Glog\n Prints Critical log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.critical\nglog critical","url":"glog.html#critical"},{"doc":"glog","title":"criticalf","content":"pub fn criticalf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Critical log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.criticalf\nglog criticalf","url":"glog.html#criticalf"},{"doc":"glog","title":"debug","content":"pub fn debug(logger: Glog, message: String) -&gt; Glog\n Prints Debug log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.debug\nglog debug","url":"glog.html#debug"},{"doc":"glog","title":"debugf","content":"pub fn debugf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Debug log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.debugf\nglog debugf","url":"glog.html#debugf"},{"doc":"glog","title":"emergency","content":"pub fn emergency(logger: Glog, message: String) -&gt; Glog\n Prints Emergency log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\n\n ### Usage\n \n import glog.{type Glog}\n\n let logger: Glog = glog.new()\n logger\n |&gt; emergency(&quot;er&quot;)\n \nSynonyms:\nglog.emergency\nglog emergency","url":"glog.html#emergency"},{"doc":"glog","title":"emergencyf","content":"pub fn emergencyf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Emergency log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\n\n ### Usage\n \n import glog.{type Glog}\n\n let logger: Glog = glog.new()\n logger\n |&gt; emergencyf(&quot;~p is the new ~p&quot;, [arg.new(&quot;foo&quot;), arg.new(&quot;bar&quot;)])\n \nSynonyms:\nglog.emergencyf\nglog emergencyf","url":"glog.html#emergencyf"},{"doc":"glog","title":"error","content":"pub fn error(logger: Glog, message: String) -&gt; Glog\n Prints Error log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.error\nglog error","url":"glog.html#error"},{"doc":"glog","title":"errorf","content":"pub fn errorf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Error log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.errorf\nglog errorf","url":"glog.html#errorf"},{"doc":"glog","title":"get_field","content":"pub fn get_field(logger: Glog, key: String) -&gt; Result(Field, Nil)\n Fetches a field if it exists from its key\nSynonyms:\nglog.get_field\nglog get_field","url":"glog.html#get_field"},{"doc":"glog","title":"has_field","content":"pub fn has_field(logger: Glog, key: String) -&gt; Bool\n Finds if a field exists from its key\nSynonyms:\nglog.has_field\nglog has_field","url":"glog.html#has_field"},{"doc":"glog","title":"info","content":"pub fn info(logger: Glog, message: String) -&gt; Glog\n Prints Info log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.info\nglog info","url":"glog.html#info"},{"doc":"glog","title":"infof","content":"pub fn infof(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Info log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.infof\nglog infof","url":"glog.html#infof"},{"doc":"glog","title":"new","content":"pub fn new() -&gt; Glog\n Initializes a new Glog representation\n\n ### Usage\n \n import glog.{Glog}\n\n let logger: Glog = glog.new()\n \nSynonyms:\nglog.new\nglog new","url":"glog.html#new"},{"doc":"glog","title":"new_with","content":"pub fn new_with(with: Option(List(Field))) -&gt; Glog\n Initializes a new Glog representation with fields\nSynonyms:\nglog.new_with\nglog new_with","url":"glog.html#new_with"},{"doc":"glog","title":"notice","content":"pub fn notice(logger: Glog, message: String) -&gt; Glog\n Prints Notice log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.notice\nglog notice","url":"glog.html#notice"},{"doc":"glog","title":"noticef","content":"pub fn noticef(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Notice log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.noticef\nglog noticef","url":"glog.html#noticef"},{"doc":"glog","title":"set_default_config","content":"pub fn set_default_config() -&gt; Nil\n Sets a default formatter for default handler\n\n This function is what we want to recommend as default format or the lib\nSynonyms:\nglog.set_default_config\nglog set_default_config","url":"glog.html#set_default_config"},{"doc":"glog","title":"set_handler_log_level","content":"pub fn set_handler_log_level(\n  handler: String,\n  lvl: ConfigLevel,\n) -&gt; Nil\n Sets log level for given handler\nSynonyms:\nglog.set_handler_log_level\nglog set_handler_log_level","url":"glog.html#set_handler_log_level"},{"doc":"glog","title":"set_primary_log_level","content":"pub fn set_primary_log_level(lvl: ConfigLevel) -&gt; Nil\n Sets log level for primary handler\nSynonyms:\nglog.set_primary_log_level\nglog set_primary_log_level","url":"glog.html#set_primary_log_level"},{"doc":"glog","title":"warning","content":"pub fn warning(logger: Glog, message: String) -&gt; Glog\n Prints Warning log with current fields stored and the given message\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.warning\nglog warning","url":"glog.html#warning"},{"doc":"glog","title":"warningf","content":"pub fn warningf(\n  logger: Glog,\n  string: String,\n  values: List(Arg),\n) -&gt; Glog\n Prints Warning log with current fields stored and the given message template and values\n\n Calling this function return a new Glog. Old Glog can still be used.\nSynonyms:\nglog.warningf\nglog warningf","url":"glog.html#warningf"},{"doc":"glog","title":"glog","content":"","url":"glog.html"}]);